@page :left {
    background: black
}

@media(min-width: 0) {
    background: white
}

@font-face {
    family-name: "A;' /**/";
}

@viewport {
    width: 110px;
}

@-ms-viewport {
    width: 100px;
}
