:root {
  --number: 1;
  --unit: 100vw;
  --color: #06c;

  --function: calc(1 + 1);
  --variable: var(--unit);

  --string: 'single quoted string';
  --string: "double quoted string";

  --square-block: [1, 2, 3];
  --round-block: (1, 2, 3);

  --empty1: ;
  --empty2: /**/;
  --empty3: !important;
  --empty4:/**/ !important;
  --empty5:/**/ ;

  --bracket-block: {1, 2, 3};
  --JSON: [1, "2", {"three": {"a":1}}, [4]];
  --javascript: function(rule) { console.log(rule) };
}

:root{--a:1}

.semicolon-less {--empty-end:/**/ }

.empty{--a: }
